# flake8:noqa
# pylint:skip-file
# isort:skip_file
# fmt:off
# Produced by 'meteoalarm-tools'@'2021-02-24UTC17:54'

#                   WARNING
# THIS FILE WAS PRODUCED BY TOOLS THAT AUTOMATICALLY
# PULL THE RELEVANT INFORMATION FROM meteoalarm.eu
#            DON'T EDIT IT MANUALLY!


regions={
"AT":{
"Burgenland":"008",
"Kärnten":"006",
"Niederösterreich":"001",
"Oberösterreich":"007",
"Osttirol":"004",
"Salzburg":"005",
"Steiermark":"009",
"Tirol":"003",
"Vorarlberg":"002",
"Wien":"010",
},
"BA":{
"Banja Luka":"003",
"Bihac":"001",
"Foca":"009",
"Livno":"005",
"Mostar":"008",
"Prijedor":"002",
"Sarajevo":"006",
"Trebinje":"010",
"Tuzla":"004",
"Visegrad":"007",
},
"BE":{
"Antwerpen / Anvers":"002",
"Belgische Küste":"801",
"Brabant":"004",
"Hainaut / Henegouwen":"005",
"Liège / Luik":"008",
"Limburg / Limbourg":"007",
"Luxembourg / Luxemburg":"001",
"Namur / Namen":"006",
"Oost Vlaanderen/Fl.Orientale":"003",
"West Vlaanderen/Fl.Occidentale":"009",
},
"BG":{
"Blagoevgrad":"001",
"Burgas":"002",
"Dobrich":"003",
"Gabrovo":"004",
"Haskovo":"005",
"Kardjali":"006",
"Kustendil":"007",
"Lovech":"008",
"Montana":"009",
"Pazardjik":"012",
"Pernik":"014",
"Pleven":"013",
"Plovdiv":"011",
"Razgrad":"016",
"Ruse":"015",
"Shumen":"019",
"Silistra":"021",
"Sliven":"020",
"Smolian":"010",
"Sofia":"018",
"Sofia city":"017",
"Stara Zagora":"022",
"Targovishte":"023",
"Varna":"026",
"Veliko Tarnova":"027",
"Vidin":"024",
"Vraca":"025",
"Yambol":"028",
},
"CH":{
"Aarau-Lenzburg":"124",
"Adelboden-Kandersteg":"122",
"Aigle - Leysin":"230",
"Ajoie":"201",
"Albulatal":"187",
"Aletschgebiet":"246",
"Alta Valmaggia":"301",
"Alto Moesano":"304",
"Amriswil":"159",
"Appenzell":"168",
"Arolla":"241",
"Basel":"101",
"Basse-GruyÞre":"220",
"Basso Moesano":"308",
"Bellinzonese":"309",
"Berne-Sense":"107",
"Bex - Villars":"235",
"Bienne - Neuchâtel":"208",
"Binntal":"250",
"Bivio-Avers":"188",
"Blenio":"303",
"Bregaglia":"312",
"Brienz-Interlaken":"128",
"Brig - nördliches Simplongebiet":"251",
"Brigels":"165",
"Broye":"214",
"Burgdorf-Limpachtal":"106",
"Conthey - Fully":"236",
"Davos":"186",
"DelÚmont - Bellelay":"203",
"Domleschg":"180",
"Effretikon":"142",
"Einsiedeln-Wõgital":"153",
"Emmen-Hochdorf":"134",
"Entlebuch":"127",
"Erstfeld-Engelberg":"147",
"Estavayer - Cudrefin":"212",
"Flims-Laax":"172",
"Flüelen-Unterschächen":"155",
"Franches-Montagnes":"202",
"Fribourg":"215",
"Frick-Leibstadt":"123",
"Frutigen-Kiental":"121",
"Fürstenland":"160",
"GenÞve":"222",
"Gersau-Engelbergertal":"146",
"Glarus Nord-Mitte":"163",
"Glarus Süd-Grosstal":"164",
"Glarus Süd-Sernftal":"171",
"GlÔne":"219",
"Goldau--geri":"145",
"Grindelwald":"130",
"Gros-de-Vaud":"218",
"Haut val de Bagnes":"238",
"Hulftegg-Untertoggenburg":"161",
"Huttwil-Willisau":"126",
"Innertkirchen-Guttannen":"138",
"Jogne - Haute-Gruyere":"228",
"Kerenzerberg-Seeztal":"170",
"Küblis-Klosters":"185",
"La Chaux-de-Fonds - Le Locle":"205",
"Landquart-Chur":"179",
"Langenthal":"117",
"Langnau-Eggiwil":"119",
"Laufental":"102",
"Lausanne - Lavaux":"225",
"Lauterbrunnen-Wilderswil":"129",
"Leventina":"302",
"Liechtenstein":"177",
"Limmattal":"132",
"Linthebene-Gaster":"162",
"Locarnese":"305",
"Lötschental - Naters":"242",
"Luganese":"310",
"Lugnez-Valsertal":"166",
"Luzern-Alpnach":"135",
"Lyss-Grenchen":"105",
"Maderanertal":"156",
"Marthalen-Stammheim":"140",
"Martigny - Verbier":"237",
"Meiringen-Gadmertal":"137",
"Mendrisiotto":"311",
"Monthey - Val d'Illiez":"232",
"Morges - Cossonay":"224",
"Moutier - Tavannes":"204",
"Muotathal":"154",
"Murten - Kerzers":"213",
"Nidau - Ins":"209",
"Niedersimmental":"110",
"nördliches Tavetsch":"157",
"Nyon - Terre Sainte":"223",
"Oberes Baselbiet":"115",
"Oberes Mattertal":"245",
"Oberes Saastal":"248",
"Obergoms":"249",
"Obersimmental":"111",
"Obertoggenburg":"169",
"Olten-Gösgen":"116",
"Oron - Haute-Broye":"226",
"Pays-d'Enhaut":"229",
"Pfungen-Hettlingen":"141",
"Plaine de l'Orbe":"217",
"Poschiavo":"313",
"Rheinfelden":"114",
"Rheintal":"175",
"Rheinwald":"174",
"Riein-Safiental":"173",
"Riviera":"307",
"Riviera vaudoises":"227",
"S'charl-d'Uina":"318",
"Saanen-Gsteig":"112",
"Saint-Cergue":"221",
"San Moritz":"315",
"Sarganserland":"178",
"Sarnen-Lungern":"136",
"Savognin":"184",
"Schaffhausen":"139",
"Schams":"181",
"Schanfigg":"183",
"Schangnau-Sigriswil":"120",
"Schiers":"182",
"Scoul-Samnaun":"319",
"Sion - Crans-Montana":"239",
"Solothurn-Rothrist":"104",
"St. Stephan-Lenk":"113",
"St.Gallen-Rorschach":"167",
"Steckborn-Müllheim":"150",
"südliches Simplongebiet":"252",
"Sumiswald-Worb":"118",
"Thal":"103",
"Thalwil-Wetzikon":"143",
"Thun-Belp":"109",
"Turbenthal-Sirnach":"151",
"Turtmanntal":"244",
"Urner Oberland":"148",
"Urserntal":"149",
"Val d'Anniviers":"243",
"Val d'Entremont - Val Ferret":"234",
"Val d'HÚrens":"240",
"Val de Ruz - Colombier":"207",
"Val de Travers":"210",
"Val Medel-Sumvitg":"158",
"Val Monastero":"314",
"Vallon de Saint-Imier":"206",
"VallÚe de Joux":"216",
"VallÚe du Trient":"233",
"Verzasca":"306",
"Vispertal - Nanztal":"247",
"Vouvry":"231",
"Wädenswil-Rüti":"152",
"Wahlern-Plaffeien":"108",
"Werdenberg":"176",
"Wohlen-Albis":"133",
"Yverdon - Bevaix":"211",
"Zernez":"317",
"Zofingen-Triengen":"125",
"Zug-Knonau":"144",
"Zuoz":"316",
"Zurzach-Bülach":"131",
},
"CY":{
"Cyprus":"001",
},
"CZ":{
"Jihočeský":"004",
"Jihomoravský":"011",
"Karlovarský":"002",
"Královéhradecký":"007",
"Liberecký":"006",
"Moravskoslezský":"001",
"Olomoucký":"012",
"Pardubický":"008",
"Plzeňský":"003",
"Praha":"014",
"Středočeský":"009",
"Ústecký":"005",
"Vysočina":"010",
"Zlínský":"013",
},
"DE":{
"Alb-Donau-Kreis und Stadt Ulm":"074",
"Altmarkkreis Salzwedel":"216",
"B.gau-Hochschwarzwald / Freiburg":"035",
"Bodenseekreis":"271",
"Bundesstadt Bonn":"289",
"Burgenlandkreis":"145",
"Darmstadt-Dieburg / Darmstadt":"047",
"Donnersbergkreis":"197",
"Eifelkreis Bitburg-Prüm":"387",
"Elbe von Hamburg bis Cuxhaven":"804",
"Elbe Wesermündung":"805",
"Ennepe-Ruhr-Kreis":"134",
"Enzkreis und Stadt Pforzheim":"050",
"Erzgebirgskreis":"343",
"Flensburg bis Femarn":"808",
"Hansestadt Bremen":"369",
"Hansestadt Hamburg":"413",
"Hansestadt Lübeck":"265",
"Hansestadt Rostock":"234",
"Heidekreis":"317",
"Helgoland":"803",
"Hochsauerlandkreis":"411",
"Hochtaunuskreis":"201",
"Hohenlohekreis":"212",
"Ilm-Kreis":"254",
"Insel Borkum":"039",
"Insel Helgoland":"422",
"Kreis Ahrweiler":"232",
"Kreis Aichach-Friedberg":"375",
"Kreis Altenburger Land":"255",
"Kreis Altenkirchen":"199",
"Kreis Altötting":"116",
"Kreis Alzey-Worms":"397",
"Kreis Amberg-Sulzbach":"353",
"Kreis Ammerland":"221",
"Kreis Anhalt-Bitterfeld":"357",
"Kreis Aurich - Binnenland":"102",
"Kreis Aurich - Küste":"103",
"Kreis Bad Dürkheim":"390",
"Kreis Bad Kissingen":"409",
"Kreis Bad Kreuznach":"143",
"Kreis Bad Tölz-Wolfratshausen":"371",
"Kreis Barnim":"264",
"Kreis Bautzen - Bergland":"086",
"Kreis Bautzen - Tiefland":"054",
"Kreis Berchtesgadener Land":"183",
"Kreis Bergstraße":"361",
"Kreis Bernkastel-Wittlich":"190",
"Kreis Biberach":"163",
"Kreis Birkenfeld":"182",
"Kreis Böblingen":"223",
"Kreis Börde":"306",
"Kreis Borken":"355",
"Kreis Calw":"152",
"Kreis Celle":"138",
"Kreis Cham":"309",
"Kreis Cloppenburg":"200",
"Kreis Cochem-Zell":"214",
"Kreis Coesfeld":"125",
"Kreis Cuxhaven - Binnenland":"030",
"Kreis Cuxhaven - Küste":"045",
"Kreis Dachau":"414",
"Kreis Dahme-Spreewald":"172",
"Kreis Deggendorf":"117",
"Kreis Diepholz":"310",
"Kreis Dillingen a.d. Donau":"354",
"Kreis Dingolfing-Landau":"251",
"Kreis Dithmarschen - Binnenland":"081",
"Kreis Dithmarschen - Küste":"091",
"Kreis Donau-Ries":"147",
"Kreis Düren":"314",
"Kreis Ebersberg":"260",
"Kreis Eichsfeld":"406",
"Kreis Eichstätt":"303",
"Kreis Elbe-Elster":"261",
"Kreis Emmendingen":"227",
"Kreis Emsland":"376",
"Kreis Erding":"339",
"Kreis Erlangen-Höchstadt":"196",
"Kreis Esslingen":"302",
"Kreis Euskirchen":"127",
"Kreis Forchheim":"191",
"Kreis Freising":"374",
"Kreis Freudenstadt":"404",
"Kreis Freyung-Grafenau":"380",
"Kreis Friesland - Binnenland":"065",
"Kreis Friesland - Küste":"104",
"Kreis Fulda":"248",
"Kreis Fürstenfeldbruck":"379",
"Kreis Garmisch-Partenkirchen":"195",
"Kreis Germersheim":"153",
"Kreis Gießen":"185",
"Kreis Gifhorn":"244",
"Kreis Göppingen":"215",
"Kreis Görlitz - Bergland":"070",
"Kreis Görlitz - Tiefland":"075",
"Kreis Goslar":"328",
"Kreis Gotha":"193",
"Kreis Göttingen":"151",
"Kreis Grafschaft Bentheim":"237",
"Kreis Greiz":"352",
"Kreis Groß-Gerau":"166",
"Kreis Günzburg":"388",
"Kreis Gütersloh":"119",
"Kreis Hameln-Pyrmont":"111",
"Kreis Hamm":"159",
"Kreis Harburg":"170",
"Kreis Harz - Bergland":"093",
"Kreis Harz - Tiefland":"048",
"Kreis Haßberge":"335",
"Kreis Havelland":"382",
"Kreis Heidenheim":"311",
"Kreis Heinsberg":"157",
"Kreis Helmstedt":"415",
"Kreis Herford":"365",
"Kreis Hersfeld-Rotenburg":"217",
"Kreis Herzogtum Lauenburg":"236",
"Kreis Hildburghausen":"305",
"Kreis Hildesheim":"384",
"Kreis Holzminden":"176",
"Kreis Höxter":"327",
"Kreis Jerichower Land":"141",
"Kreis Kelheim":"165",
"Kreis Kitzingen":"399",
"Kreis Kleve":"283",
"Kreis Konstanz":"419",
"Kreis Kronach":"296",
"Kreis Kulmbach":"245",
"Kreis Kusel":"160",
"Kreis Landsberg am Lech":"130",
"Kreis Leer":"069",
"Kreis Leipzig":"179",
"Kreis Lichtenfels":"178",
"Kreis Limburg-Weilburg":"341",
"Kreis Lindau":"280",
"Kreis Lippe":"407",
"Kreis Lörrach":"312",
"Kreis Lüchow-Dannenberg":"122",
"Kreis Ludwigsburg":"241",
"Kreis Ludwigslust-Parchim - Ost":"076",
"Kreis Ludwigslust-Parchim - West":"107",
"Kreis Lüneburg":"383",
"Kreis Main-Spessart":"304",
"Kreis Mainz-Bingen / Mainz":"097",
"Kreis Mansfeld-Südharz":"180",
"Kreis Marburg-Biedenkopf":"362",
"Kreis Märkisch-Oderland":"233",
"Kreis Mayen-Koblenz":"351",
"Kreis Meißen":"416",
"Kreis Merzig-Wadern":"137",
"Kreis Mettmann":"250",
"Kreis Miesbach":"293",
"Kreis Miltenberg":"266",
"Kreis Minden-Lübbecke":"131",
"Kreis Mittelsachsen - Bergland":"099",
"Kreis Mittelsachsen - Tiefland":"094",
"Kreis Mühldorf a. Inn":"332",
"Kreis Neu-Ulm":"348",
"Kreis Neuburg-Schrobenhausen":"402",
"Kreis Neumarkt i.d. OPf.":"219",
"Kreis Neunkirchen":"274",
"Kreis Neustadt a.d. Waldnaab":"321",
"Kreis Neuwied":"270",
"Kreis Nienburg":"298",
"Kreis Nordfriesland - Binnenland":"106",
"Kreis Nordfriesland - Küste":"095",
"Kreis Nordhausen":"373",
"Kreis Nordsachsen - Nord":"028",
"Kreis Nordsachsen - Süd":"071",
"Kreis Northeim":"294",
"Kreis Nürnberger Land":"358",
"Kreis Oberallgäu":"330",
"Kreis Oberhavel":"322",
"Kreis Oberspreewald-Lausitz":"140",
"Kreis Oder-Spree":"242",
"Kreis Olpe":"229",
"Kreis Ostallgäu":"239",
"Kreis Osterholz":"209",
"Kreis Osterode am Harz":"326",
"Kreis Ostholstein - Binnenland":"073",
"Kreis Ostholstein - Küste":"061",
"Kreis Ostprignitz-Ruppin":"313",
"Kreis Paderborn":"324",
"Kreis Peine":"257",
"Kreis Pfaffenhofen a.d. Ilm":"420",
"Kreis Pinneberg":"058",
"Kreis Plön - Binnenland":"088",
"Kreis Plön - Küste":"037",
"Kreis Potsdam-Mittelmark":"187",
"Kreis Prignitz":"247",
"Kreis Rastatt":"146",
"Kreis Ravensburg":"344",
"Kreis Recklinghausen":"224",
"Kreis Regen":"391",
"Kreis Reutlingen":"276",
"Kreis Rhön-Grabfeld":"121",
"Kreis Rostock - Binnenland Nord":"036",
"Kreis Rostock - Binnenland Süd":"027",
"Kreis Rostock - Küste":"055",
"Kreis Rotenburg (Wümme)":"142",
"Kreis Roth":"338",
"Kreis Rottal-Inn":"421",
"Kreis Rottweil":"285",
"Kreis Saalfeld-Rudolstadt":"115",
"Kreis Saarlouis":"240",
"Kreis Schaumburg":"225",
"Kreis Schmalkalden-Meiningen":"203",
"Kreis Schwäbisch Hall":"340",
"Kreis Schwandorf":"112",
"Kreis Segeberg":"181",
"Kreis Siegen-Wittgenstein":"269",
"Kreis Sigmaringen":"320",
"Kreis Soest":"155",
"Kreis Sömmerda":"323",
"Kreis Sonneberg":"206",
"Kreis Spree-Neiße":"129",
"Kreis St. Wendel":"136",
"Kreis Stade":"222",
"Kreis Starnberg":"267",
"Kreis Steinburg":"158",
"Kreis Steinfurt":"273",
"Kreis Stendal":"325",
"Kreis Stormarn":"400",
"Kreis Südliche Weinstraße":"405",
"Kreis Südwestpfalz / Pirmasens":"098",
"Kreis Teltow-Fläming":"345",
"Kreis Tirschenreuth":"398",
"Kreis Traunstein":"288",
"Kreis Trier-Saarburg / Trier":"051",
"Kreis Tübingen":"301",
"Kreis Tuttlingen":"175",
"Kreis Uckermark":"144",
"Kreis Uelzen":"350",
"Kreis und Stadt Ansbach":"078",
"Kreis und Stadt Aschaffenburg":"057",
"Kreis und Stadt Augsburg":"096",
"Kreis und Stadt Bamberg":"046",
"Kreis und Stadt Bayreuth":"042",
"Kreis und Stadt Coburg":"087",
"Kreis und Stadt Fürth":"020",
"Kreis und Stadt Heilbronn":"080",
"Kreis und Stadt Hof":"089",
"Kreis und Stadt Kaiserslautern":"084",
"Kreis und Stadt Karlsruhe":"109",
"Kreis und Stadt Kassel":"026",
"Kreis und Stadt Landshut":"021",
"Kreis und Stadt München":"056",
"Kreis und Stadt Offenbach":"041",
"Kreis und Stadt Oldenburg":"079",
"Kreis und Stadt Osnabrück":"024",
"Kreis und Stadt Passau":"066",
"Kreis und Stadt Regensburg":"049",
"Kreis und Stadt Rosenheim":"029",
"Kreis und Stadt Schweinfurt":"105",
"Kreis und Stadt Würzburg":"077",
"Kreis Unna":"235",
"Kreis Unterallgäu":"249",
"Kreis Vechta":"188",
"Kreis Verden":"393",
"Kreis Viersen":"113",
"Kreis Vulkaneifel":"356",
"Kreis Waldeck-Frankenberg":"218",
"Kreis Waldshut":"281",
"Kreis Warendorf":"171",
"Kreis Weilheim-Schongau":"342",
"Kreis Weimarer Land":"194",
"Kreis Weißenburg-Gunzenhausen":"410",
"Kreis Wesel":"253",
"Kreis Wesermarsch - Binnenland":"064",
"Kreis Wesermarsch - Küste":"101",
"Kreis Wittenberg":"263",
"Kreis Wittmund - Binnenland":"053",
"Kreis Wittmund - Küste":"083",
"Kreis Wolfenbüttel":"220",
"Kreis Wunsiedel":"213",
"Kreis Zwickau - Bergland":"044",
"Kreis Zwickau - Tiefland":"040",
"Kyffhäuserkreis":"262",
"Lahn-Dill-Kreis":"395",
"Main-Kinzig-Kreis":"118",
"Main-Tauber-Kreis":"308",
"Main-Taunus-Kreis":"412",
"Märkischer Kreis":"389",
"Mecklenburg. Seenplatte - Mitte":"025",
"Mecklenburg. Seenplatte - Südost":"082",
"Mecklenburg. Seenplatte - West":"059",
"Neckar-Odenwald-Kreis":"290",
"Neustadt/Aisch - Bad Windsheim":"372",
"Nordfriesische Küste":"801",
"Nordwestmecklenburg - Binnenland":"085",
"Nordwestmecklenburg - Küste":"033",
"Oberbergischer Kreis":"243",
"Odenwaldkreis":"360",
"Ortenaukreis":"329",
"Ostalbkreis":"346",
"Ostfriesische Küste":"802",
"Östlich Fehmarn bis Rügen":"806",
"Östlich Rügen":"807",
"Region Hannover":"169",
"Regionalverband Saarbrücken":"189",
"Rems-Murr-Kreis":"284",
"Rendsburg-Eckernförde - Binnenl.":"031",
"Rendsburg-Eckernförde - Küste":"067",
"Rhein-Erft-Kreis":"367",
"Rhein-Hunsrück-Kreis":"292",
"Rhein-Kreis Neuss":"164",
"Rhein-Lahn-Kreis":"300",
"Rhein-Neckar-Kreis / Heidelberg":"110",
"Rhein-Pfalz-Kreis / Ludwigshafen":"068",
"Rhein-Sieg-Kreis":"198",
"Rheingau-Taunus-Kreis":"268",
"Rheinisch-Bergischer Kreis":"366",
"Saale-Holzland-Kreis":"386",
"Saale-Orla-Kreis":"318",
"Saalekreis":"204",
"Saarpfalz-Kreis":"238",
"Sächs. Schweiz-Osterzgeb.-ö. Bgl":"063",
"Sächs. Schweiz-Osterzgeb.-Tiefl.":"038",
"Sächs. Schweiz-Osterzgeb.-w. Bgl":"092",
"Salzlandkreis":"228",
"Schleswig-Flensburg - Binnenland":"062",
"Schleswig-Flensburg - Küste":"060",
"Schwalm-Eder-Kreis":"177",
"Schwarzwald-Baar-Kreis":"408",
"Stadt Amberg":"205",
"Stadt Baden-Baden":"347",
"Stadt Berlin":"202",
"Stadt Bielefeld":"378",
"Stadt Bochum":"396",
"Stadt Bottrop":"295",
"Stadt Brandenburg":"392",
"Stadt Braunschweig":"275",
"Stadt Bremerhaven":"173",
"Stadt Chemnitz":"297",
"Stadt Cottbus":"394",
"Stadt Delmenhorst":"337",
"Stadt Dessau-Roßlau":"259",
"Stadt Dortmund":"230",
"Stadt Dresden":"363",
"Stadt Duisburg":"336",
"Stadt Düsseldorf":"128",
"Stadt Eisenach":"286",
"Stadt Emden":"154",
"Stadt Erfurt":"359",
"Stadt Erlangen":"139",
"Stadt Essen":"364",
"Stadt Flensburg":"156",
"Stadt Frankenthal":"370",
"Stadt Frankfurt (Oder)":"272",
"Stadt Frankfurt am Main":"133",
"Stadt Gelsenkirchen":"161",
"Stadt Gera":"162",
"Stadt Hagen":"291",
"Stadt Halle (Saale)":"135",
"Stadt Herne":"211",
"Stadt Ingolstadt":"282",
"Stadt Jena":"417",
"Stadt Kaufbeuren":"120",
"Stadt Kempten (Allgäu)":"381",
"Stadt Kiel":"418",
"Stadt Koblenz":"277",
"Stadt Köln":"299",
"Stadt Krefeld":"377",
"Stadt Landau in der Pfalz":"368",
"Stadt Leipzig":"126",
"Stadt Leverkusen":"256",
"Stadt Magdeburg":"278",
"Stadt Mannheim":"184",
"Stadt Memmingen":"174",
"Stadt Mönchengladbach":"114",
"Stadt Mülheim an der Ruhr":"132",
"Stadt Münster":"167",
"Stadt Neumünster":"192",
"Stadt Neustadt an der Weinstraße":"210",
"Stadt Nürnberg":"150",
"Stadt Oberhausen":"401",
"Stadt Potsdam":"385",
"Stadt Remscheid":"252",
"Stadt Salzgitter":"334",
"Stadt Schwabach":"246",
"Stadt Schwerin":"331",
"Stadt Solingen":"186",
"Stadt Speyer":"287",
"Stadt Stuttgart":"226",
"Stadt Suhl":"208",
"Stadt Weiden in der Oberpfalz":"316",
"Stadt Weimar":"307",
"Stadt Wiesbaden":"403",
"Stadt Wilhelmshaven":"124",
"Stadt Wolfsburg":"319",
"Stadt Worms":"333",
"Stadt Wuppertal":"207",
"Stadt Zweibrücken":"349",
"StädteRegion Aachen":"258",
"Straubing-Bogen / Straubing":"043",
"Unstrut-Hainich-Kreis":"123",
"Vogelsbergkreis":"315",
"Vogtlandkreis - Bergland":"023",
"Vogtlandkreis - Tiefland":"108",
"Vorpommern-Greifsw. - Binnenl. N":"022",
"Vorpommern-Greifsw. - Binnenl. S":"034",
"Vorpommern-Greifsw. - Küste Nord":"072",
"Vorpommern-Greifsw. - Küste Süd":"100",
"Vorpommern-Rügen - Binnenland":"090",
"Vorpommern-Rügen - Insel Rügen":"052",
"Vorpommern-Rügen - Küste":"032",
"Wartburgkreis":"149",
"Werra-Meissner-Kreis":"279",
"Westerwaldkreis":"148",
"Wetteraukreis":"231",
"Zollernalbkreis":"168",
},
"DK":{
"Århus Bugt":"807",
"Bornholm":"003",
"Bornholms kyst":"820",
"Centrale Vestkyst":"802",
"Fyn":"006",
"København og Nordsjælland":"008",
"Lolland-Falsters sydkyst":"813",
"Midt- og Vestjylland":"002",
"Nordfyns kyst":"809",
"Nordjylland":"001",
"Nordlige Lillebælt":"808",
"Nordsjællands kyst":"817",
"Sejrøbugt":"816",
"Skagerraks kyst":"803",
"Smålandsfarvandet":"814",
"Syd- og Sønderjylland":"005",
"Sydfynske Øhav":"811",
"Sydlige Lillebælt":"810",
"Sydøstsjællands kyst":"819",
"Vadehavet":"801",
"Vest- og Sydsjælland + Lolland-Falster":"007",
"Vestlige Kattegat":"804",
"Vestlige Limfjord":"806",
"Vestlige Storebælt":"812",
"Øresund":"818",
"Østjylland":"004",
"Østlige Limfjord":"805",
"Østlige Storebælt":"815",
},
"EE":{
"Eastern Gulf of Finnland":"801",
"Harjumaa":"004",
"Hiiumaa":"002",
"Ida-Virumaa":"006",
"Järvamaa":"008",
"Jõgevamaa":"011",
"Lääne-Virumaa":"005",
"Läänemaa":"003",
"Moonsund":"802",
"Northern Baltic":"805",
"Northern Gulf of Riga":"804",
"Pärnumaa":"009",
"Põlvamaa":"014",
"Raplamaa":"007",
"Saaremaa":"001",
"Tartumaa":"012",
"Valgamaa":"013",
"Viljandimaa":"010",
"Võrumaa":"015",
"Western Gulf of Finnland":"803",
},
"ES":{
"A Mariña":"206",
"Albarracín y Jiloca":"102",
"Alcaraz y Segura":"162",
"Alcarria conquense":"168",
"Alcarria de Guadalajara":"173",
"Altiplano de Murcia":"221",
"Ampurdán":"184",
"Andévalo y Condado":"086",
"Antequera":"092",
"Aracena":"085",
"Área metropolitana de Tenerife":"131",
"Axarquía":"095",
"Bajo Aragón de Teruel":"104",
"Barros y Serena":"196",
"Bierzo de León":"146",
"Bizkaia interior":"236",
"Bizkaia litoral":"235",
"Campiña cordobesa":"079",
"Campiña gaditana":"075",
"Campiña sevillana":"097",
"Campo de Cartagena y Mazarrón":"225",
"Cantabria del Ebro":"136",
"Capital y Montes de Jaén":"091",
"Cazorla y Segura":"089",
"Central y Valles Mineros":"111",
"Centro de Huesca":"100",
"Centro de Lugo":"207",
"Centro de Navarra":"227",
"Centro y valle de Villaverde":"135",
"Ceuta":"250",
"Cinco Villas de Zaragoza":"105",
"Condado de Treviño":"142",
"Cordillera Cantábrica de Burgos":"140",
"Cordillera Cantábrica de León":"145",
"Cordillera Cantábrica de Palencia":"148",
"Cordillera y Picos de Europa":"112",
"Costa - A Mariña":"845",
"Costa - Ampurdán":"890",
"Costa - Área metropolitana de Tenerife":"884",
"Costa - Axarquía":"855",
"Costa - Bizkaia litoral":"841",
"Costa - Campo de Cartagena y Mazarrón":"860",
"Costa - Ceuta":"871",
"Costa - Costa granadina":"856",
"Costa - El Hierro":"879",
"Costa - Este de La Palma":"881",
"Costa - Este, sur y oeste de Gran Canaria":"886",
"Costa - Este, sur y oeste de Tenerife":"885",
"Costa - Estrecho":"853",
"Costa - Fuerteventura":"888",
"Costa - Gipuzkoa litoral":"840",
"Costa - Ibiza y Formentera":"873",
"Costa - La Gomera":"882",
"Costa - Lanzarote":"889",
"Costa - Levante almeriense":"858",
"Costa - Levante mallorquín":"877",
"Costa - Litoral cántabro":"842",
"Costa - Litoral de Barcelona":"869",
"Costa - Litoral de Huelva":"851",
"Costa - Litoral gaditano":"852",
"Costa - Litoral norte de Alicante":"862",
"Costa - Litoral norte de Castellón":"866",
"Costa - Litoral norte de Tarragona":"868",
"Costa - Litoral norte de Valencia":"864",
"Costa - Litoral occidental asturiano":"844",
"Costa - Litoral oriental asturiano":"843",
"Costa - Litoral sur de Alicante":"861",
"Costa - Litoral sur de Castellón":"865",
"Costa - Litoral sur de Girona":"870",
"Costa - Litoral sur de Tarragona":"867",
"Costa - Litoral sur de Valencia":"863",
"Costa - Melilla":"872",
"Costa - Menorca":"878",
"Costa - Miño de Pontevedra":"850",
"Costa - Noroeste de A Coruña":"846",
"Costa - Norte de Gran Canaria":"887",
"Costa - Norte de Tenerife":"883",
"Costa - Norte y nordeste de Mallorca":"876",
"Costa - Oeste de A Coruña":"847",
"Costa - Oeste de La Palma":"880",
"Costa - Poniente y Almería Capital":"857",
"Costa - Rias Baixas":"849",
"Costa - Sierra Tramontana":"875",
"Costa - Sol y Guadalhorce":"854",
"Costa - Sur de Mallorca":"874",
"Costa - Suroeste de A Coruña":"848",
"Costa granadina":"084",
"Costa Valle Guadalentín Lorca Águilas":"859",
"Cuenca del Genil":"081",
"Cuenca del Nervión":"230",
"Cumbres de Gran Canaria":"121",
"Cumbres de La Palma":"125",
"Depresión central de Barcelona":"179",
"Depresión central de Lleida":"188",
"Depresión central de Tarragona":"189",
"El Hierro":"129",
"Este de La Palma":"126",
"Este, sur y oeste de Gran Canaria":"122",
"Este, sur y oeste de Tenerife":"132",
"Estrecho":"077",
"Fuerteventura":"124",
"Gipuzkoa interior":"234",
"Gipuzkoa litoral":"233",
"Grazalema":"074",
"Guadix y Baza":"082",
"Gúdar y Maestrazgo":"103",
"Hellín y Almansa":"163",
"Ibérica de Burgos":"144",
"Ibérica de Soria":"155",
"Ibérica riojana":"238",
"Ibérica zaragozana":"106",
"Ibiza y Formentera":"113",
"Interior de A Coruña":"204",
"Interior de Alicante":"240",
"Interior de Mallorca":"116",
"Interior de Pontevedra":"216",
"Interior norte de Castellón":"242",
"Interior norte de Valencia":"246",
"Interior sur de Castellón":"244",
"Interior sur de Valencia":"248",
"La Gomera":"128",
"La Mancha albaceteña":"161",
"La Mancha conquense":"170",
"La Mancha de Ciudad Real":"165",
"La Mancha toledana":"177",
"La Siberia extremeña":"195",
"Lanzarote":"123",
"Levante almeriense":"073",
"Levante mallorquín":"118",
"Liébana":"134",
"Litoral cántabro":"133",
"Litoral de Barcelona":"181",
"Litoral de Huelva":"087",
"Litoral gaditano":"076",
"Litoral norte de Alicante":"239",
"Litoral norte de Castellón":"243",
"Litoral norte de Tarragona":"191",
"Litoral norte de Valencia":"247",
"Litoral occidental asturiano":"108",
"Litoral oriental asturiano":"109",
"Litoral sur de Alicante":"241",
"Litoral sur de Castellón":"245",
"Litoral sur de Girona":"185",
"Litoral sur de Tarragona":"192",
"Litoral sur de Valencia":"249",
"Llanada alavesa":"231",
"Melilla":"251",
"Menorca":"119",
"Meseta cacereña":"200",
"Meseta de Ávila":"137",
"Meseta de Burgos":"143",
"Meseta de León":"147",
"Meseta de Palencia":"149",
"Meseta de Salamanca":"150",
"Meseta de Segovia":"153",
"Meseta de Soria":"156",
"Meseta de Valladolid":"158",
"Meseta de Zamora":"160",
"Metropolitana y Henares":"219",
"Miño de Ourense":"211",
"Miño de Pontevedra":"217",
"Montaña de Lugo":"208",
"Montaña de Ourense":"213",
"Montes de Toledo":"176",
"Montes del norte y Anchuras":"164",
"Morena y Condado":"088",
"Nacimiento y Campo de Tabernas":"071",
"Nevada y Alpujarras":"083",
"Noroeste de A Coruña":"202",
"Noroeste de Murcia":"222",
"Noroeste de Ourense":"210",
"Norte de Burgos":"141",
"Norte de Cáceres":"198",
"Norte de Gran Canaria":"120",
"Norte de Tenerife":"130",
"Norte y nordeste de Mallorca":"115",
"Oeste de A Coruña":"203",
"Oeste de La Palma":"127",
"Parameras de Molina":"172",
"Pirineo de Girona":"182",
"Pirineo de Lleida":"187",
"Pirineo navarro":"228",
"Pirineo oscense":"099",
"Poniente y Almería Capital":"072",
"Prelitoral de Barcelona":"180",
"Prelitoral de Girona":"183",
"Prelitoral norte de Tarragona":"190",
"Prelitoral sur de Tarragona":"193",
"Prepirineo de Barcelona":"178",
"Rias Baixas":"215",
"Ribera del Ebro de La Rioja":"237",
"Ribera del Ebro de Navarra":"229",
"Ribera del Ebro de Zaragoza":"107",
"Rioja alavesa":"232",
"Ronda":"093",
"Sanabria":"159",
"Serranía de Cuenca":"169",
"Serranía de Guadalajara":"171",
"Sierra de Madrid":"218",
"Sierra de San Vicente":"174",
"Sierra norte de Sevilla":"096",
"Sierra sur de Sevilla":"098",
"Sierra Tramontana":"114",
"Sierra y Pedroches":"078",
"Sierras de Alcudia y Madrona":"167",
"Sistema Central de Ávila":"138",
"Sistema Central de Salamanca":"151",
"Sistema Central de Segovia":"154",
"Sistema Central de Soria":"157",
"Sol y Guadalhorce":"094",
"Subbética cordobesa":"080",
"Sur de Ávila":"139",
"Sur de Badajoz":"197",
"Sur de Huesca":"101",
"Sur de Lugo":"209",
"Sur de Mallorca":"117",
"Sur de Ourense":"212",
"Sur de Salamanca":"152",
"Sur, Vegas y Oeste":"220",
"Suroccidental asturiana":"110",
"Suroeste de A Coruña":"205",
"Tajo y Alagón":"199",
"Valdeorras":"214",
"Valle de Arán":"186",
"Valle del Almanzora y Los Vélez":"070",
"Valle del Guadalentín, Lorca y Águilas":"224",
"Valle del Guadalquivir de Jaén":"090",
"Valle del Guadiana":"166",
"Valle del Tajo":"175",
"Vega del Segura":"223",
"Vegas del Guadiana":"194",
"Vertiente cantábrica de Navarra":"226",
"Villuercas y Montánchez":"201",
},
"FI":{
"Ahvenanmaa":"043",
"Eastern Gulf of Finland":"805",
"Eastern Part of northern Baltic":"812",
"Enontekiö":"004",
"Etelä-Karjala":"040",
"Etelä-Pohjanmaa":"030",
"Etelä-Savo":"041",
"Inari":"003",
"Kainuu":"026",
"Kanta-Häme":"033",
"Kemi":"016",
"Kemijärvi":"008",
"Keminmaa":"017",
"Keski-Pohjanmaa":"028",
"Keski-Suomi":"039",
"Kittilä":"009",
"Kolari":"011",
"Kuusamo":"025",
"Kymenlaakso":"036",
"Muonio":"010",
"Northern Bay of Bothnia":"809",
"Northern Sea of Bothnia":"802",
"Päijät-Häme":"037",
"Pelkosenniemi":"006",
"Pello":"012",
"Pirkanmaa":"038",
"Pohjanmaa":"029",
"Pohjois-Karjala":"001",
"Pohjois-Pohjanmaa Eteläinen":"020",
"Pohjois-Savo":"027",
"Posio":"022",
"Pudasjärvi":"023",
"Ranua":"021",
"Rovaniemi":"014",
"Salla":"007",
"Satakunta":"031",
"Savukoski":"042",
"Sea of Aaland":"813",
"Sea of Archipelago":"811",
"Simo":"019",
"Sodankylä":"005",
"Southern Bay of Bothnia":"810",
"Southern Sea of Bothnia":"807",
"Taivalkoski":"024",
"Tervola":"018",
"The Quark":"801",
"Tornio":"015",
"Utsjoki":"002",
"Uusimaa":"034",
"Varsinais-Suomi":"032",
"Western Gulf of Finland":"806",
"Western Part of northern Baltic":"803",
"Ylitornio":"013",
},
"FR":{
"Ain":"039",
"Aisne":"073",
"Allier":"043",
"Alpes de Haute Provence":"032",
"Alpes Maritimes":"029",
"Andorre":"001",
"Ardèche":"026",
"Ardennes":"074",
"Ariège":"008",
"Aube":"075",
"Aude":"007",
"Aveyron":"021",
"Bas Rhin":"086",
"Bouches du Rhône":"027",
"Calvados":"052",
"Cantal":"024",
"Charente":"016",
"Charente Maritime":"015",
"Cher":"059",
"Corrèze":"018",
"Corse du Sud":"090",
"Côte d'Or":"078",
"Côtes d'Armor":"047",
"Creuse":"041",
"Deux Sèvres":"094",
"Dordogne":"017",
"Doubs":"080",
"Drôme":"031",
"Essonne":"066",
"Eure":"056",
"Eure et Loir":"063",
"Finistère":"046",
"Gard":"022",
"Gers":"005",
"Gironde":"014",
"Haut Rhin":"083",
"Haute Corse":"089",
"Haute Garonne":"009",
"Haute Loire":"025",
"Haute Marne":"085",
"Haute Saône":"082",
"Haute Savoie":"035",
"Haute Vienne":"019",
"Hautes Alpes":"033",
"Hautes Pyrénées":"003",
"Hérault":"020",
"Ille et Vilaine":"050",
"Indre":"042",
"Indre et Loire":"093",
"Isère":"034",
"Jura":"079",
"Landes":"004",
"Loir et Cher":"058",
"Loire":"037",
"Loire Atlantique":"049",
"Loiret":"061",
"Lot":"013",
"Lot et Garonne":"012",
"Lozère":"023",
"Maine et Loire":"092",
"Manche":"051",
"Marne":"076",
"Mayenne":"053",
"Meurthe et Moselle":"088",
"Meuse":"002",
"Morbihan":"048",
"Moselle":"087",
"Nièvre":"060",
"Nord":"070",
"Oise":"072",
"Orne":"054",
"Paris et Petite Couronne":"067",
"Pas de Calais":"069",
"Puy de Dôme":"040",
"Pyrénées Atlantiques":"091",
"Pyrénées Orientales":"006",
"Rhône":"038",
"Saône et Loire":"077",
"Sarthe":"057",
"Savoie":"036",
"Seine et Marne":"068",
"Seine Maritime":"055",
"Somme":"071",
"Tarn":"011",
"Tarn et Garonne":"010",
"Territoire de Belfort":"081",
"Val d'Oise":"065",
"Var":"028",
"Vaucluse":"030",
"Vendée":"044",
"Vienne":"045",
"Vosges":"084",
"Yonne":"062",
"Yvelines":"064",
},
"GR":{
"Attiki":"011",
"Central Makedonia":"007",
"Dodekanisa Islands":"013",
"East Makedonia":"005",
"East Peloponnisos":"015",
"East Sterea &amp; Evvoia":"003",
"Epirus":"008",
"Ionion Islands":"010",
"Kriti":"016",
"Kyklades":"012",
"North East Aegean Islands":"014",
"Thessalia":"001",
"Thraki":"004",
"West Makedonia":"006",
"West Peloponnisos":"009",
"West Sterea":"002",
},
"HR":{
"Dubrovnik regija":"007",
"Gospic regija":"004",
"Karlovac regija":"003",
"Knin regija":"001",
"Kvarner and Kvarneric region":"802",
"Middle Dalmatia region":"805",
"North Dalmatia region":"804",
"Osijek regija":"005",
"Rijeka regija":"006",
"South Dalmatia region":"806",
"Split regija":"008",
"Velebit channel region":"803",
"West Istrian coast region":"801",
"Zagreb regija":"002",
},
"HU":{
"Central Hungary":"006",
"Central Transdanubia":"003",
"Northern Great Plain":"001",
"Northern Hungary":"007",
"Southern Great Plain":"005",
"Southern Transdanubia":"004",
"Western Transdanubia":"002",
},
"IE":{
"Carlow":"020",
"Cavan":"027",
"Clare":"014",
"Cork":"007",
"Donegal":"018",
"Dublin":"012",
"Galway":"015",
"Ireland North-West":"802",
"Ireland South":"804",
"Ireland West":"801",
"Irish Sea":"803",
"Kerry":"008",
"Kildare":"030",
"Kilkenny":"021",
"Laois":"022",
"Leitrim":"029",
"Limerick":"013",
"Longford":"025",
"Louth":"019",
"Mayo":"016",
"Meath":"023",
"Monaghan":"031",
"Offaly":"028",
"Roscommon":"026",
"Sligo":"017",
"Tipperary":"006",
"Waterford":"009",
"Westmeath":"024",
"Wexford":"010",
"Wicklow":"011",
},
"IL":{
"Beit She'an Valley":"033",
"Carmel":"030",
"Carmel  Coast":"029",
"Central Shoreline":"802",
"Eestern Lower Galilee":"027",
"Eestern Negev":"047",
"Eestern Upper Galilee":"023",
"Elat Mountains":"050",
"Gilboa":"034",
"Gush Dan":"036",
"Hula Valley":"024",
"Jerusalem Mountains":"040",
"Jezreel Valley":"032",
"Judean Desert":"043",
"Judean Lowlands":"039",
"Kinarot Valley":"028",
"Modi'in Region":"037",
"Negev Mountains":"046",
"North-Eastern Negev":"042",
"North-Western Negev":"041",
"Northern Arava":"045",
"Northern Shoreline":"801",
"Plain of Manasseh":"031",
"Sharon":"035",
"Southern Arava":"049",
"Southern Coast":"038",
"Southern Negev":"048",
"Southern Shoreline":"803",
"Western Galilee":"021",
"Western Lower Galilee":"026",
"Western Negev":"044",
"Western Upper Galilee":"022",
"Zevulun Valley":"025",
},
"IS":{
"Breidafjordur - Westnorthwest Iceland":"004",
"Central highlands - Uninhabited part of Iceland":"011",
"East Iceland":"008",
"Eastfjords":"009",
"Faxafloi - Southwest Iceland":"003",
"Northeast Iceland":"007",
"Northwest Iceland":"006",
"Reykjavik - Capital Region":"001",
"South Iceland":"002",
"Southeast Iceland":"010",
"Westfjords":"005",
},
"IT":{
"Abruzzo":"013",
"Basilicata":"017",
"Calabria":"001",
"Campania":"016",
"Emilia e Romagna":"008",
"Friuli VeneziaGiulia":"020",
"Lazio":"012",
"Liguria":"007",
"Lombardia":"003",
"Marche":"011",
"Molise":"014",
"Piemonte":"005",
"Puglia":"015",
"Sardegna":"019",
"Sicilia":"018",
"Toscana":"009",
"Trentino Alto Adige":"002",
"Umbria":"010",
"Valle d'Aosta":"004",
"Veneto":"006",
},
"LT":{
"Alytaus apskritis":"001",
"Coast":"801",
"Kauno apskritis":"002",
"Klaipėdos apskritis":"003",
"Marijampolės apskritis":"004",
"Panevėžio apskritis":"005",
"Šiaulių apskritis":"006",
"Tauragės apskritis":"007",
"Telšių apskritis":"008",
"Utenos apskritis":"009",
"Vilniaus apskritis":"010",
},
"LU":{
"Luxembourg North":"002",
"Luxembourg South":"001",
},
"LV":{
"Central Baltic east":"803",
"Gulf of Riga east":"802",
"Gulf of Riga south":"801",
"Gulf of Riga west":"804",
"Kurzeme":"004",
"Latgale":"002",
"Vidzeme":"001",
"Zemgale":"003",
},
"MD":{
"Anenii Noi":"026",
"Basarabeasca":"034",
"Briceni":"001",
"Cahul":"036",
"Calarasi":"017",
"Cantemir":"033",
"Causeni":"029",
"Cimislia":"028",
"Criuleni":"023",
"Donduseni":"004",
"Drochia":"005",
"Dubasari":"021",
"Edinet":"002",
"Falesti":"009",
"Floresti":"012",
"Glodeni":"008",
"Hincesti":"024",
"Ialoveni":"025",
"Leova":"027",
"mun. Balti":"010",
"mun. Chisinau":"022",
"mun. Tighina":"030",
"Nisporeni":"019",
"Ocnita":"003",
"Orhei":"018",
"Rezina":"015",
"Riscani":"007",
"Singerei":"011",
"Soldanesti":"013",
"Soroca":"006",
"Stefan-Voda":"032",
"Straseni":"020",
"Taraclia":"035",
"Telenesti":"014",
"Transnistria":"031",
"Ungheni":"016",
"UTA Gagauza":"037",
},
"ME":{
"Adriatic coast":"002",
"Central":"003",
"Continental and Mountains":"001",
},
"MK":{
"North-Vardar":"001",
"Ohrid-Prespa":"003",
"Osogovo-Maleshevo":"002",
"Pelagonia":"004",
"Polog-Poreche":"005",
"South-Vardar":"006",
},
"MT":{
"Malta":"001",
},
"NL":{
"Drenthe":"018",
"Flevoland":"008",
"Friesland":"017",
"Gelderland":"014",
"Groningen":"007",
"Hoek van Holland":"802",
"IJmuiden":"803",
"IJsselmeer":"807",
"Limburg":"012",
"Noord-Brabant":"013",
"Noord-Holland":"011",
"Overijssel":"016",
"Rottum":"805",
"Texel":"804",
"Utrecht":"015",
"Vlissingen":"801",
"Waddeneilanden":"019",
"Waddenzee":"806",
"Zeeland":"010",
"Zuid-Holland":"009",
},
"NO":{
"Akershus":"011",
"Aust-Agder":"001",
"Aust-Agder kyst":"802",
"Buskerud":"013",
"Finnmark":"015",
"Finnmark kyst":"803",
"Hedmark":"008",
"Hordaland":"017",
"Hordaland kyst":"810",
"Møre og Romsdal":"005",
"Møre og Romsdal kyst":"808",
"Nord-Trøndelag":"006",
"Nord-Trøndelag kyst":"806",
"Nordland":"019",
"Nordland kyst":"805",
"Oppland":"009",
"Oslo":"010",
"Rogaland":"003",
"Rogaland kyst":"811",
"Sogn og Fjordane":"004",
"Sogn og Fjordane kyst":"809",
"Sør-Trøndelag":"018",
"Sør-Trøndelag kyst":"807",
"Telemark":"012",
"Telemark kyst":"814",
"Troms":"020",
"Troms kyst":"804",
"Vest-Agder":"016",
"Vest-Agder kyst":"812",
"Vestfold":"002",
"Vestfold kyst":"813",
"Østfold":"014",
"Østfold kyst":"801",
},
"PL":{
"Aleksandrowski":"0401",
"Augustowski":"2001",
"Bartoszycki":"2801",
"Będziński":"2401",
"Bełchatowski":"1001",
"Bialski":"0601",
"Biała Podlaska":"0661",
"Białobrzeski":"1401",
"Białogardzki":"3201",
"Białostocki":"2002",
"Białystok":"2061",
"Bielski":"2003",
"Bielski":"2402",
"Bielsko-Biała":"2461",
"Bieruńsko-Lędziński":"2414",
"Bieszczadzki":"1801",
"Biłgorajski":"0602",
"Bocheński":"1201",
"Bolesławiecki":"0201",
"Braniewski":"2802",
"Brodnicki":"0402",
"Brzeski":"1202",
"Brzeski":"1601",
"Brzeziński":"1021",
"Brzozowski":"1802",
"Buski":"2601",
"Bydgoski":"0403",
"Bydgoszcz":"0461",
"Bytom":"2462",
"Bytowski":"2201",
"Central coastal zone":"804",
"Chełm":"0662",
"Chełmiński":"0404",
"Chełmski":"0603",
"Chodzieski":"3001",
"Chojnicki":"2202",
"Chorzów":"2463",
"Choszczeński":"3202",
"Chrzanowski":"1203",
"Ciechanowski":"1402",
"Cieszyński":"2403",
"Czarnkowsko-Trzcianecki":"3002",
"Częstochowa":"2464",
"Częstochowski":"2404",
"Człuchowski":"2203",
"Dąbrowa Górnicza":"2465",
"Dąbrowski":"1204",
"Dębicki":"1803",
"Drawski":"3203",
"Działdowski":"2803",
"Dzierżoniowski":"0202",
"Eastern coastal zone":"805",
"Elbląg":"2861",
"Elbląski":"2804",
"Ełcki":"2805",
"Garwoliński":"1403",
"Gdańsk":"2261",
"Gdański":"2204",
"Gdynia":"2262",
"Giżycki":"2806",
"Gliwice":"2466",
"Gliwicki":"2405",
"Gnieźnieński":"3003",
"Goleniowski":"3204",
"Golubsko-Dobrzyński":"0405",
"Gorlicki":"1205",
"Górowski":"0204",
"Gorzów Wielkopolski":"0861",
"Gorzowski":"0801",
"Gostyniński":"1404",
"Gostyński":"3004",
"Gołdapski":"2818",
"Grajewski":"2004",
"Grodziski":"3005",
"Grodziski":"1405",
"Grójecki":"1406",
"Grudziądz":"0462",
"Grudziądzki":"0406",
"Gryficki":"3205",
"Gryfiński":"3206",
"Głogowski":"0203",
"Głubczycki":"1602",
"Hajnowski":"2005",
"Hrubieszowski":"0604",
"Inowrocławski":"0407",
"Iławski":"2807",
"Janowski":"0605",
"Jarociński":"3006",
"Jarosławski":"1804",
"Jasielski":"1805",
"Jastrzębie-Zdrój":"2467",
"Jaworski":"0205",
"Jaworzno":"2468",
"Jędrzejowski":"2602",
"Jelenia Góra":"0261",
"Jeleniogórski":"0206",
"Kaliski":"3007",
"Kalisz":"3061",
"Kamiennogórski":"0207",
"Kamieński":"3207",
"Kartuski":"2205",
"Katowice":"2469",
"Kazimierski":"2603",
"Kędzierzyńsko-Kozielski":"1603",
"Kępiński":"3008",
"Kętrzyński":"2808",
"Kielce":"2661",
"Kielecki":"2604",
"Kluczborski":"1604",
"Kolbuszowski":"1806",
"Kolneński":"2006",
"Kolski":"3009",
"Konecki":"2605",
"Konin":"3062",
"Koniński":"3010",
"Kościański":"3011",
"Kościerski":"2206",
"Koszalin":"3261",
"Koszaliński":"3209",
"Kozienicki":"1407",
"Kołobrzeski":"3208",
"Kraków":"1261",
"Krakowski":"1206",
"Krapkowicki":"1605",
"Kraśnicki":"0607",
"Krasnostawski":"0606",
"Krośnieński":"0802",
"Krośnieński":"1807",
"Krosno":"1861",
"Krotoszyński":"3012",
"Kutnowski":"1002",
"Kwidzyński":"2207",
"Kłobucki":"2406",
"Kłodzki":"0208",
"Lęborski":"2208",
"Legionowski":"1408",
"Legnica":"0262",
"Legnicki":"0209",
"Leski":"1821",
"Leszczyński":"3013",
"Leszno":"3063",
"Leżajski":"1808",
"Lidzbarski":"2809",
"Limanowski":"1207",
"Lipnowski":"0408",
"Lipski":"1409",
"Lubaczowski":"1809",
"Lubański":"0210",
"Lubartowski":"0608",
"Lubelski":"0609",
"Lubiński":"0211",
"Lublin":"0663",
"Lubliniecki":"2407",
"Lwówecki":"0212",
"Makowski":"1411",
"Malborski":"2209",
"Miechowski":"1208",
"Międzychodzki":"3014",
"Międzyrzecki":"0803",
"Mielecki":"1811",
"Mikołowski":"2408",
"Milicki":"0213",
"Miński":"1412",
"Mogileński":"0409",
"Moniecki":"2008",
"Mrągowski":"2810",
"Myślenicki":"1209",
"Myśliborski":"3210",
"Myszkowski":"2409",
"Mysłowice":"2470",
"Mławski":"1413",
"Nakielski":"0410",
"Namysłowski":"1606",
"Nidzicki":"2811",
"Niżański":"1812",
"Nowodworski":"1414",
"Nowodworski":"2210",
"Nowomiejski":"2812",
"Nowosądecki":"1210",
"Nowosolski":"0804",
"Nowotarski":"1211",
"Nowotomyski":"3015",
"Nowy Sącz":"1262",
"Nyski":"1607",
"Obornicki":"3016",
"Olecki":"2813",
"Oleski":"1608",
"Oleśnicki":"0214",
"Olkuski":"1212",
"Olsztyn":"2862",
"Olsztyński":"2814",
"Opatowski":"2606",
"Opoczyński":"1007",
"Opole":"1661",
"Opolski":"0612",
"Opolski":"1609",
"Ostródzki":"2815",
"Ostrowiecki":"2607",
"Ostrowski":"3017",
"Ostrowski":"1416",
"Ostrołęcki":"1415",
"Ostrołęka":"1461",
"Ostrzeszowski":"3018",
"Oświęcimski":"1213",
"Otwocki":"1417",
"Oławski":"0215",
"Pabianicki":"1008",
"Pajęczański":"1009",
"Parczewski":"0613",
"Piaseczyński":"1418",
"Piekary Śląskie":"2471",
"Pilski":"3019",
"Pińczowski":"2608",
"Piotrków Trybunalski":"1062",
"Piotrkowski":"1010",
"Piski":"2816",
"Pleszewski":"3020",
"Poddębicki":"1011",
"Policki":"3211",
"Polkowicki":"0216",
"Poznań":"3064",
"Poznański":"3021",
"Proszowicki":"1214",
"Prudnicki":"1610",
"Pruszkowski":"1421",
"Przasnyski":"1422",
"Przemyski":"1813",
"Przemyśl":"1862",
"Przeworski":"1814",
"Przysuski":"1423",
"Pszczyński":"2410",
"Pucki":"2211",
"Puławski":"0614",
"Pułtuski":"1424",
"Pyrzycki":"3212",
"Płock":"1462",
"Płocki":"1419",
"Płoński":"1420",
"Raciborski":"2411",
"Radom":"1463",
"Radomski":"1425",
"Radomszczański":"1012",
"Radziejowski":"0411",
"Radzyński":"0615",
"Rawicki":"3022",
"Rawski":"1013",
"Ropczycko-Sędziszowski":"1815",
"Ruda Śląska":"2472",
"Rybnicki":"2412",
"Rybnik":"2473",
"Rycki":"0616",
"Rypiński":"0412",
"Rzeszów":"1863",
"Rzeszowski":"1816",
"Sandomierski":"2609",
"Sanocki":"1817",
"Sejneński":"2009",
"Sępoleński":"0413",
"Siedlce":"1464",
"Siedlecki":"1426",
"Siemianowice Śląskie":"2474",
"Siemiatycki":"2010",
"Sieradzki":"1014",
"Sierpecki":"1427",
"Skarżyski":"2610",
"Skierniewice":"1063",
"Skierniewicki":"1015",
"Sochaczewski":"1428",
"Sokólski":"2011",
"Sokołowski":"1429",
"Sopot":"2264",
"Sosnowiec":"2475",
"Średzki":"3025",
"Średzki":"0218",
"Śremski":"3026",
"Stalowowolski":"1818",
"Starachowicki":"2611",
"Stargardzki":"3214",
"Starogardzki":"2213",
"Staszowski":"2612",
"Strefa Brzegowa Wschodnia":"801",
"Strefa Brzegowa Zachodnia":"802",
"Strzelecki":"1611",
"Strzelecko-Drezdenecki":"0806",
"Strzeliński":"0217",
"Strzyżowski":"1819",
"Sulęciński":"0807",
"Suski":"1215",
"Suwalski":"2012",
"Suwałki":"2063",
"Świdnicki":"0617",
"Świdnicki":"0219",
"Świdwiński":"3216",
"Świebodziński":"0808",
"Świecki":"0414",
"Świętochłowice":"2476",
"Świnoujście":"3263",
"Szamotulski":"3024",
"Szczecin":"3262",
"Szczecinecki":"3215",
"Szczycieński":"2817",
"Sztumski":"2216",
"Szydłowiecki":"1430",
"Sławieński":"3213",
"Słubicki":"0805",
"Słupecki":"3023",
"Słupsk":"2263",
"Słupski":"2212",
"Tarnobrzeg":"1864",
"Tarnobrzeski":"1820",
"Tarnogórski":"2413",
"Tarnów":"1263",
"Tarnowski":"1216",
"Tatrzański":"1217",
"Tczewski":"2214",
"Tomaszowski":"1016",
"Tomaszowski":"0618",
"Toruń":"0463",
"Toruński":"0415",
"Trzebnicki":"0220",
"Tucholski":"0416",
"Turecki":"3027",
"Tychy":"2477",
"Wąbrzeski":"0417",
"Wadowicki":"1218",
"Wągrowiecki":"3028",
"Warszawa":"1465",
"Warszawski Zachodni":"1432",
"Wałbrzych":"0265",
"Wałbrzyski":"0221",
"Wałecki":"3217",
"Węgorzewski":"2819",
"Węgrowski":"1433",
"Wejherowski":"2215",
"Western coastal zone":"803",
"Wielicki":"1219",
"Wieluński":"1017",
"Wieruszowski":"1018",
"Wodzisławski":"2415",
"Wolsztyński":"3029",
"Wołomiński":"1434",
"Wołowski":"0222",
"Wrocław":"0264",
"Wrocławski":"0223",
"Wrzesiński":"3030",
"Wschowski":"0812",
"Wysokomazowiecki":"2013",
"Wyszkowski":"1435",
"Włocławek":"0464",
"Włocławski":"0418",
"Włodawski":"0619",
"Włoszczowski":"2613",
"Ząbkowicki":"0224",
"Zabrze":"2478",
"Żagański":"0810",
"Zambrowski":"2014",
"Zamojski":"0620",
"Zamość":"0664",
"Żarski":"0811",
"Zawierciański":"2416",
"Zduńskowolski":"1019",
"Zgierski":"1020",
"Zgorzelecki":"0225",
"Zielona Góra":"0862",
"Zielonogórski":"0809",
"Żniński":"0419",
"Żory":"2479",
"Żuromiński":"1437",
"Zwoleński":"1436",
"Żyrardowski":"1438",
"Żywiecki":"2417",
"Złotoryjski":"0226",
"Złotowski":"3031",
"Łańcucki":"1810",
"Łaski":"1003",
"Łęczycki":"1004",
"Łęczyński":"0610",
"Łobeski":"3218",
"Łódź":"1061",
"Łódzki Wschodni":"1006",
"Łomża":"2062",
"Łomżyński":"2007",
"Łosicki":"1410",
"Łowicki":"1005",
"Łukowski":"0611",
},
"PT":{
"AÇORES - Grupo Central":"002",
"AÇORES - Grupo Ocidental":"001",
"AÇORES - Grupo Oriental":"003",
"AVEIRO":"010",
"BEJA":"005",
"BRAGA":"022",
"BRAGANÇA":"008",
"CASTELO BRANCO":"014",
"COIMBRA":"013",
"ÉVORA":"019",
"FARO":"021",
"GUARDA":"012",
"LEIRIA":"015",
"LISBOA":"016",
"Madeira - Costa Norte":"025",
"Madeira - Costa Sul":"024",
"Madeira - Porto Santo":"026",
"Madeira - Regiões Montanhosas":"023",
"PORTALEGRE":"018",
"PORTO":"009",
"SANTARÉM":"017",
"SETÚBAL":"020",
"VIANA DO CASTELO":"006",
"VILA REAL":"007",
"VISEU":"011",
},
"RO":{
"Alba":"001",
"Arad":"020",
"Arges":"036",
"Bacau":"015",
"Bihor":"019",
"Bistria-Nasaud":"017",
"Botosani":"005",
"Braila":"013",
"Brasov":"034",
"Bucuresti":"027",
"Buzau":"031",
"Calarasi":"011",
"Caras-Serverin":"022",
"Cluj":"040",
"Constanta":"010",
"Covasna":"033",
"Dambovita":"029",
"Dolj":"024",
"Galati":"008",
"Giurgiu":"026",
"Gorj":"038",
"Harghita":"016",
"Hunedoara":"039",
"Ialomita":"012",
"Iasi":"006",
"Ilfov":"028",
"Maramures":"003",
"Mehedinti":"023",
"Mures":"041",
"Neamt":"014",
"Olt":"035",
"Prahova":"030",
"Salaj":"018",
"Satu Mare":"002",
"Sibiu":"042",
"Suceava":"004",
"Teleorman":"025",
"Timis":"021",
"Tulcea":"009",
"Valcea":"037",
"Vaslui":"007",
"Vrancea":"032",
},
"RS":{
"Југозападна Србија":"006",
"Југоисточна Србија":"005",
"Банат":"001",
"Бачка":"002",
"Београд":"003",
"Западна Србија":"011",
"Источна Србија":"004",
"Косово":"007",
"Поморавље":"008",
"Срем":"009",
"Шумадија":"010",
},
"SE":{
"Bay of Bothnia":"801",
"Blekinge":"001",
"Bohuskusten+Göteborg":"015",
"Central Baltic":"806",
"Dalafjällen":"027",
"Dalarna":"012",
"Gävleborgs inland":"029",
"Gävleborgs kustland":"025",
"Gotland":"035",
"Halland":"038",
"Härjedalsfjällen":"028",
"Inre Dalsland":"039",
"Jämtland":"031",
"Jämtlandsfjällen":"030",
"Kalmar":"006",
"Kategatt":"810",
"Norra Lapplandsfjällen":"034",
"Norra Västergötland":"011",
"Norrbottens inland":"026",
"Norrbottens kustland":"020",
"North Sea of Bothnia":"803",
"Northern Baltic":"807",
"Öland":"036",
"Örebro":"014",
"Östergötland":"010",
"Österlen":"037",
"Östra Jönköping":"009",
"Östra Kronoberg":"004",
"Roslagskusten":"022",
"Sea of Aaland":"805",
"Sjuhärad+Göta älv":"040",
"Skagerrak":"811",
"Skåne":"002",
"Södra Lapplandsfjällen":"033",
"Sörmland":"013",
"South Sea of Bothnia":"804",
"Southern Baltic":"808",
"Stockholm":"021",
"Syd Vättern":"008",
"Sydväst Vänern":"007",
"The Quark":"802",
"The Sound":"809",
"Upplandskusten":"016",
"Uppsala":"023",
"Vänern":"813",
"Värmland":"017",
"Västerbottens inland":"032",
"Västerbottens kustland":"019",
"Västernorrland":"018",
"Västmanland":"024",
"Västra Jönköping":"005",
"Västra Kronoberg":"003",
"Waters of Gotland":"812",
},
"SI":{
"Slovenija - jugovzhod / SE":"010",
"Slovenija - jugozahod / SW":"008",
"Slovenija - morje / Sea":"801",
"Slovenija - osrednja / Central":"009",
"Slovenija - severovzhod / NE":"006",
"Slovenija - severozahod / NW":"007",
},
"SK":{
"Bánovce nad Bebravou":"301",
"Banská Bystrica":"601",
"Banská Štiavnica":"602",
"Bardejov":"701",
"Bratislava":"100",
"Brezno":"603",
"Bytča":"501",
"Čadca":"502",
"Detva":"604",
"Dolný Kubín":"503",
"Dunajská Streda":"201",
"Galanta":"202",
"Gelnica":"121",
"Hlohovec":"203",
"Humenné":"702",
"Ilava":"302",
"Kežmarok":"703",
"Komárno":"401",
"Košice":"120",
"Košice - okolie":"122",
"Krupina":"605",
"Kysucké Nové Mesto":"504",
"Levice":"402",
"Levoča":"704",
"Liptovský Mikuláš":"505",
"Lučenec":"606",
"Malacky":"106",
"Martin":"506",
"Medzilaborce":"705",
"Michalovce":"123",
"Myjava":"303",
"Námestovo":"507",
"Nitra":"403",
"Nové Mesto nad Váhom":"304",
"Nové Zámky":"404",
"Partizánske":"305",
"Pezinok":"107",
"Piešťany":"204",
"Poltár":"607",
"Poprad":"706",
"Považská Bystrica":"306",
"Prešov":"707",
"Prievidza":"307",
"Púchov":"308",
"Revúca":"608",
"Rimavská Sobota":"609",
"Rožňava":"124",
"Ružomberok":"508",
"Sabinov":"708",
"Šaľa":"405",
"Senec":"108",
"Senica":"205",
"Skalica":"206",
"Snina":"709",
"Sobrance":"125",
"Spišská Nová Ves":"126",
"Stará Ľubovňa":"710",
"Stropkov":"711",
"Svidník":"712",
"Topoľčany":"406",
"Trebišov":"127",
"Trenčín":"309",
"Trnava":"207",
"Turčianske Teplice":"509",
"Tvrdošín":"510",
"Veľký Krtíš":"610",
"Vranov nad Topľou":"713",
"Žarnovica":"612",
"Žiar nad Hronom":"613",
"Žilina":"511",
"Zlaté Moravce":"407",
"Zvolen":"611",
},
"UK":{
"Dumfries and Galloway":"006",
"East Midlands":"011",
"East of England":"012",
"Grampian":"015",
"Highland &amp; Islands":"002",
"London &amp; South East":"013",
"Lothian &amp; Borders":"004",
"North East":"007",
"North West":"009",
"Northern Ireland":"014",
"South West":"001",
"Strathclyde":"005",
"Tayside, Central &amp; Fife":"003",
"Wales":"016",
"West Midlands":"010",
"Yorkshire and the Humber":"008",
},
}


awt={
"1":"Wind",
"2":"Snow/Ice",
"3":"Thunderstorms",
"4":"Fog",
"5":"Extreme high temperature",
"6":"Extreme low temperature",
"7":"Coastal Event",
"8":"Forestfire",
"9":"Avalanches",
"10":"Rain",
"12":"Flood",
"13":"Rain-Flood",
}


awl={
"0":("White","Missing, insufficient, outdated or suspicious data."),
"1":("Green","No particular awareness of the weather is required."),
"2":("Yellow","The weather is potentially dangerous. The weather phenomena that have been forecast are not unusual, but be attentive if you intend to practice activities exposed to meteorological risks. Keep informed about the expected meteorological conditions and do not take any avoidable risk."),
"3":("Orange","The weather is dangerous. Unusual meteorological phenomena have been forecast. Damage and casualties are likely to happen. Be very vigilant and keep regularly informed about the detailed expected meteorological conditions. Be aware of the risks that might be unavoidable. Follow any advice given by your authorities."),
"4":("Red","The weather is very dangerous. Exceptionally intense meteorological phenomena have been forecast. Major damage and accidents are likely, in many cases with threat to life and limb, over a wide area. Keep frequently informed about detailed expected meteorological conditions and risks. Follow orders and any advice given by your authorities under all circumstances, be prepared for extraordinary measures."),
}


countries={
"AT":("AT-Austria","de,en","deutsch,english"),
"BA":("BA-Bosnia-Herzegovina","bs,en","/"),
"BE":("BE-Belgium","nl,fr","nederlands,français"),
"BG":("BG-Bulgaria","bg","български"),
"CH":("CH-Switzerland","en","english"),
"CY":("CY-Cyprus","en,el","english,Ελληνικά"),
"CZ":("CZ-Czechia","cs,en","čeština,english"),
"DE":("DE-Germany","de,en","deutsch,english"),
"DK":("DK-Denmark","dk,en","dansk,english"),
"EE":("EE-Estonia","et,en",". "),
"ES":("ES-Spain","es,en","español,english"),
"FI":("FI-Finland","fi,sv,en","suomi,svenska,english"),
"FR":("FR-France","fr,en","français,english"),
"GR":("GR-Greece","en,el","english,Ελληνικά"),
"HR":("HR-Croatia","hr,en","hrvatski,english"),
"HU":("HU-Hungary","hu,en","magyar,english"),
"IE":("IE-Ireland","en","english"),
"IL":("IL-Israel","en,he","english,עברית"),
"IS":("IS-Iceland","is,en","íslenska,english"),
"IT":("IT-Italy","it,en","italiano,english"),
"LT":("LT-Lithuania","lt","lietuviu"),
"LU":("LU-Luxembourg","fr,de,en","français,deutsch,english"),
"LV":("LV-Latvia","en,lv","english,latviešu"),
"MD":("MD-Moldova","ro",""),
"ME":("ME-Montenegro","en,sr","english,Црногорски"),
"MK":("MK-Republic%20of%20North%20Macedonia","mk",""),
"MT":("MT-Malta","en,mt","English,Malti"),
"NL":("NL-Netherlands","nl,en","nederlands,english"),
"NO":("NO-Norway","no,en","norsk,english"),
"PL":("PL-Poland","pl,en","polski,english"),
"PT":("PT-Portugal","pt,en","português,english"),
"RO":("RO-Romania","ro,en","româna,english"),
"RS":("RS-Serbia","en,sr","english,српски"),
"SE":("SE-Sweden","sv,en","svenska,english"),
"SI":("SI-Slovenia","sl,en","slovenščina,english"),
"SK":("SK-Slovakia","sk,en","slovenčina,english"),
"UK":("UK-United%20Kingdom","en",""),
}


KEYS=("alert_id","country","region","awareness_type","awareness_level","from","until","message","message_id","published","languages",)
awl_to_num={'White':0,'Green':1,'Yellow':2,'Orange':3,'Red':4}
awareness_levels=(('White','Missing, insufficient, outdated or suspicious data.'), ('Green','No particular awareness of the weather is required.'), ('Yellow','The weather is potentially dangerous. The weather phenomena that have been forecast are not unusual, but be attentive if you intend to practice activities exposed to meteorological risks. Keep informed about the expected meteorological conditions and do not take any avoidable risk.'), ('Orange','The weather is dangerous. Unusual meteorological phenomena have been forecast. Damage and casualties are likely to happen. Be very vigilant and keep regularly informed about the detailed expected meteorological conditions. Be aware of the risks that might be unavoidable. Follow any advice given by your authorities.'), ('Red','The weather is very dangerous. Exceptionally intense meteorological phenomena have been forecast. Major damage and accidents are likely, in many cases with threat to life and limb, over a wide area. Keep frequently informed about detailed expected meteorological conditions and risks. Follow orders and any advice given by your authorities under all circumstances, be prepared for extraordinary measures.'))
awareness_types=('Wind','Snow/Ice','Thunderstorms','Fog','Extreme high temperature','Extreme low temperature','Coastal Event','Forestfire','Avalanches','Rain','Flood','Rain-Flood')
countries_list=('AT','BA','BE','BG','CH','CY','CZ','DE','DK','EE','ES','FI','FR','GR','HR','HU','IE','IL','IS','IT','LT','LU','LV','MD','ME','MK','MT','NL','NO','PL','PT','RO','RS','SE','SI','SK','UK')
languages_list=('bg','bs','cs','de','dk','el','en','es','et','fi','fr','he','hr','hu','is','it','lt','lv','mk','mt','nl','no','pl','pt','ro','sk','sl','sr','sv')



from ._client import MeteoAlarm
from ._helpers import countries_iso as country_iso_map
from ._helpers import get_languages, get_regions, service_health_check, utcnow2iso8601
from ._resources import (
    KEYS,
    awareness_levels,
    awareness_types,
    countries_list,
    languages_list,
)
from .exceptions import (
    MeteoAlarmException,
    MeteoAlarmMissingInfo,
    MeteoAlarmParseError,
    MeteoAlarmServiceError,
    MeteoAlarmUnavailableLanguageError,
    MeteoAlarmUnrecognizedCountryError,
    MeteoAlarmUnrecognizedRegionError,
)

__version__ = "0.3.8"



import re
from zlib import crc32

from ._helpers import _days_since, cet2iso8601, strdt2iso8601
from ._resources import awl, awl_to_num, awt, countries
from .exceptions import (
    MeteoAlarmMissingInfo,
    MeteoAlarmParseError,
    MeteoAlarmServiceError,
)

# pylint: disable=too-many-locals
GREEN_MESSAGE = "No special awareness required"
DAYS_PAST_TO_WHITE = 3

RE_DESCRIPTION = re.compile(r"<description>(.*?)</description", re.I | re.M | re.S)
RE_PUBDATE = re.compile(r"<pubDate>(.*?)</pubDate>", re.I | re.M | re.S)

RE_TR = re.compile(r"<tr(.*?)</tr>", re.I | re.M | re.S)
RE_AWT = re.compile(r'alt="awt:(.*?) ', re.I | re.M | re.S)
RE_AWL = re.compile(r'level:(.*?)"', re.I | re.M | re.S)
RE_FROM = re.compile(r"From: </b><i>(.*?)</i><b>", re.I | re.M | re.S)
RE_UNTIL = re.compile(r"Until: </b><i>(.*?)</i>", re.I | re.M | re.S)
RE_MSG = re.compile(r"<td>(.*?)</td>", re.I | re.M | re.S)

RE_WS = re.compile(r"\s+", re.I | re.M | re.S)
RE_EOL = re.compile(r"\n", re.I | re.M | re.S)


def clean(msg):
    msg = re.sub(RE_EOL, " ", msg)
    msg = re.sub(RE_WS, " ", msg)
    msg = msg.replace("\u200b", "").replace("\u200c", "")
    msg = msg.replace("&lt;", "<").replace("&gt;", ">")
    return msg.strip()


def lang_parser(msg, lang, country):
    try:
        langs = countries.get(country)[1].split(",")
        quirk = countries.get(country)[2].split(",")
        for i, v in enumerate(langs):
            if v == lang:
                idx = i
                break
        # SPECIAL CASE 1
        if len(quirk) == 1:
            if len(langs) == 1:
                parsed = msg.replace(quirk[-1], "").strip(": ")
            else:
                if quirk[-1] in msg:
                    parsed = msg.split(quirk[-1])[idx].strip(": ")
                else:
                    parsed = ""
            return parsed if parsed else msg
        # SPECIAL CASE 2
        if idx == len(langs) - 1:
            m = msg.split(quirk[-1])[1]
            parsed = m.replace(quirk[-1], "").strip(": ")
            return parsed if parsed else msg
        # NORMAL CASE
        RE_LANG = re.compile(
            r"{}(.*?){}".format(quirk[idx], quirk[idx + 1]), re.I | re.M | re.S,
        )
        parsed = RE_LANG.search(msg).group(1).strip(": ")
        return parsed if parsed else msg
    except Exception:  # pylint: disable=broad-except
        return msg


def parser(rss, country, region, language):
    try:

        # pub_parser & WHITE (missing info)
        pub_date = RE_PUBDATE.search(rss).group(1)[5:]
        if _days_since(pub_date) > DAYS_PAST_TO_WHITE:
            raise MeteoAlarmMissingInfo

        # table_parser
        data = RE_DESCRIPTION.findall(rss)
        table = data[1] if data else ""
        if not table:
            return ()

        # rows_parser
        result = []
        ids = []
        rows = RE_TR.findall(table)
        rows = [r for r in rows if "Today<" not in r and "Tomorrow<" not in r]
        for i, row in enumerate(rows):

            if i % 2 == 0:
                # get: awt, awl, from and until from rows 0, 2, 4, ...
                try:
                    atype = RE_AWT.search(row).group(1)
                    alevel = RE_AWL.search(row).group(1)
                    from_date = RE_FROM.search(row).group(1)
                    until_date = RE_UNTIL.search(row).group(1)
                except AttributeError:
                    continue
            else:
                # get: msg from rows 1, 3, 5, ...
                if GREEN_MESSAGE in row:
                    continue
                msg = RE_MSG.search(row).group(1)
                msg = clean(msg)
                if language:
                    msg = lang_parser(msg, language, country)

                mcrc = crc32(
                    bytes(
                        region
                        + atype
                        + from_date
                        + until_date
                        + alevel
                        + msg
                        + pub_date,
                        "utf-8",
                    ),
                )
                if mcrc in ids:
                    continue
                ids.append(mcrc)

                acrc = crc32(bytes(region + atype + from_date[0:12], "utf-8"))

                result.append(
                    {
                        "alert_id": acrc,
                        "country": country.upper(),
                        "region": region,
                        "awareness_type": awt[atype],
                        "awareness_level": awl[alevel][0],
                        "from": cet2iso8601(from_date),
                        "until": cet2iso8601(until_date),
                        "message": msg,
                        "message_id": mcrc,
                        "published": strdt2iso8601(pub_date),
                        "languages": [language]
                        if language
                        else countries.get(country)[1].split(","),
                    },
                )

        return tuple(
            sorted(
                result,
                key=lambda d: (d.get("from"), -awl_to_num[d.get("awareness_level")]),
            ),
        )

    except MeteoAlarmMissingInfo:
        raise MeteoAlarmServiceError()
    except Exception:
        raise MeteoAlarmParseError()



from ._helpers import get_languages, get_regions, service_health_check
from ._parser import parser
from ._resources import awareness_levels, awareness_types
from ._resources import countries_list as _countries
from ._resources import regions
from ._webquery import query
from .exceptions import (
    MeteoAlarmServiceError,
    MeteoAlarmUnavailableLanguageError,
    MeteoAlarmUnrecognizedCountryError,
    MeteoAlarmUnrecognizedRegionError,
)

TIMEOUT = 20


class MeteoAlarm:
    def __init__(self, country, region, language=None, timeout=TIMEOUT):
        try:
            country = country.upper()
        except AttributeError:
            raise MeteoAlarmUnrecognizedCountryError()
        if country not in _countries:
            raise MeteoAlarmUnrecognizedCountryError()
        self._country = country
        self._region = region
        try:
            code = regions[country][region]
        except KeyError:
            raise MeteoAlarmUnrecognizedRegionError()
        if language:
            language = language.lower()
        if language and language not in get_languages(country):
            raise MeteoAlarmUnavailableLanguageError()
        self._lang = language
        url = "https://www.meteoalarm.eu/documents/rss/{iso}/{country}{code}.rss".format(
            iso=country.lower(), country=country.upper(), code=code,
        )
        self._url = url
        self._timeout = timeout

    @staticmethod
    def countries():
        return _countries

    @staticmethod
    def awareness_levels():
        return awareness_levels

    @staticmethod
    def awareness_types():
        return awareness_types

    def health_check(self, timeout=2):
        return service_health_check(self._url, timeout)

    def country_regions(self):
        return get_regions(self._country)

    def country_languages(self):
        return get_languages(self._country)

    def alerts(self):
        try:
            tmfast = int(0.3 * self._timeout)
            tmslow = int(0.7 * self._timeout)
            data = query(self._url, timeout=tmfast) or ""
            if not data:
                data = query(self._url, timeout=tmslow)
            rss = data.decode("UTF-8", "ignore") if data else ""
            if not rss:
                return ()
        except MeteoAlarmServiceError:
            raise MeteoAlarmServiceError()
        return parser(rss, self._country, self._region, self._lang)
